/*
Copyright © 2022 Volodymyr Patuta me@vpatuta.xyz

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
package cmd

import (
	"strconv"
	"strings"

	"github.com/spf13/cobra"
)

func sliceAtoi(s []string) []int {
	var res []int
	for _, i := range s {
		j, err := strconv.Atoi(i)
		if err != nil {
			panic(err)
		}
		res = append(res, j)
	}

	return res
}

// newCmd represents the new command
var newCmd = &cobra.Command{
	Use:   "new",
	Short: "Create new todo",
	Long: `Create new todo with optional due date using '-d DATE'.

You can also mark todo as completed when creating it with '-c'.`,
	Args: cobra.MinimumNArgs(1),
	Run: func(cmd *cobra.Command, args []string) {
		dateString, err := cmd.Flags().GetString("due")
		errPanic(err, "")
		comp, err := cmd.Flags().GetBool("complete")
		errPanic(err, "")
		createTodo(strings.Join(args, " "), dateString, comp)
	},
}

func init() {
	rootCmd.AddCommand(newCmd)
	newCmd.Flags().StringP("due", "d", "", "due date")
	newCmd.Flags().BoolP("complete", "c", false, "mark todo as completed")
}
